/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   TrackingChain.cxx
/// \date   14.09.2023
/// \brief  A chain class to execute CA tracking algorithm in online reconstruction (implementation)
/// \author S.Zharko <s.zharko@gsi.de>

#include "TrackingChain.h"

#include <boost/filesystem.hpp>

#include "CaConstants.h"
#include "CaInitManager.h"
#include "CaParameters.h"

using cbm::algo::TrackingChain;
using cbm::algo::ca::InitManager;
using cbm::algo::ca::Parameters;
using cbm::algo::ca::Track;
using cbm::algo::ca::constants::clrs::CL;   // clear text
using cbm::algo::ca::constants::clrs::GNb;  // grin bald text

// ---------------------------------------------------------------------------------------------------------------------
//
void TrackingChain::Init()
{
  // ------ Reading parameters from binary
  std::string paramFileBase = "mcbm_beam_2022_05_23_nickel.ca.par";  // TODO: Get the setup name from Opts()
  auto paramFile            = Opts().ParamsDir();
  paramFile /= paramFileBase;
  L_(info) << "Tracking Chain: reading CA parameters file " << GNb << paramFile.string() << CL << '\n';
  auto manager = InitManager {};
  manager.ReadParametersObject(paramFile.string());
  auto parameters = manager.TakeParameters();

  L_(info) << "Tracking Chain: parameters object: \n" << parameters.ToString(1) << '\n';
}

// ---------------------------------------------------------------------------------------------------------------------
//
std::vector<Track> TrackingChain::Run(/*vectors of hits*/)
{
  std::vector<Track> vRecoTracks;
  return vRecoTracks;
}

// ---------------------------------------------------------------------------------------------------------------------
//
void TrackingChain::Finalize() {}
