/* Copyright (C) 2010-2021 Frankfurt Institute for Advanced Studies, Goethe-Universität Frankfurt, Frankfurt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Maksym Zyzak, Igor Kulakov [committer], Sergey Gorbunov */

#ifndef L1Def_h
#define L1Def_h

// #define FAST_CODE // FAST_CODE = more unsafe

#include <iostream>

#ifdef FAST_CODE

#define L1_NO_ASSERT  // use with asserts, etc.

#else  // FAST_CODE


#endif  // FAST_CODE


#if defined(NDEBUG) || defined(L1_NO_ASSERT)

// Prints expression value to the std::cout
#define L1_SHOW(expr)

// Prints file and line information to the std::cout
#define L1_SHOWF(msg)

#else

#define L1_SHOW(expr)                                                                                                  \
  std::cout << __FILE__ << ":" << __LINE__ << ": \033[01;38;5;208m" << (#expr) << "\033[0m = " << (expr) << "\n"
#define L1_SHOWF(msg)                                                                                                  \
  std::cout << "(!) " << __FILE__ << ":" << __LINE__ << ": \033[01;38;5;208m" << (#msg) << "\033[0m\n"
#define L1_SHOWCONTAINER(cont)                                                                                         \
  std::cout << __FILE__ << ":" << __LINE__ << ": \033[01;38;5;208m" << (#cont) << "\033[0m: ";                         \
  std::for_each(cont.cbegin(), cont.cend(), [](const auto& el) { std::cout << el << ' '; });                           \
  std::cout << '\n';

#endif

#endif
